@@ -371,12 +371,49 @@ def property(componentID: "Component identifier or ATLAS serial number",
             "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
 
 
+def comment(identifier: "ID for the comment to be attached to (can be a ATLAS serial number in case of a component)",
+            comment: "Comment to attach (can also be an array)",
+            isTest: "If you want to attach to test instead of component" = False):
+    "Attach a comment to a component or test"
+    try:
+        if isinstance(comment, str):
+            comment = [comment]
+        assert isinstance(comment, list)
+
+        # Workaround for a very annoying bug in the db
+        if len(comment) == 1:
+            comment += [""]
+
+        if isTest:
+            data = {
+                "testRun": identifier,
+                "comments": comment
+            }
+            client = itkdb.Client()
+            client.post('createTestRunComment', data=data)
+        else:
+            data = {
+                "component": identifier,
+                "comments": comment
+            }
+            client = itkdb.Client()
+            client.post('createComponentComment', data=data)
+
+        logger.info(f"Attached comment(s) to {identifier}")
+    except Exception as e:
+        logger.error(e)
+        logger.error("Error while trying to get connection to DB")
+        logger.info(
+            "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
+
+
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
                         attach, tests, stage,
                         skeleton, upload, testruns,
-                        testfile, assemble, property])
+                        testfile, assemble, property,
+                        comment])
     parser.dispatch()
 
 
